import pyhausbus.HausBusUtils as HausBusUtils
from enum import Enum

class ESensorType(Enum):
  eUnknown=0
  eTemperature=1
  eHumidity=2
  eDewPoint=3
  eDistance=4
  eBrightness=5
  ePower=6
  eCounter=7
  eAnalogInput=8
  eModBusRegister=9
  eCO2=10
  eTVOC=11
  ePressure=12
  eVoltage=13
  SER_UNKNOWN=-1

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    checkValue = HausBusUtils.bytesToInt(data, offset)
    for act in ESensorType.__members__.values():
      if (act.value == checkValue):
        return act

    return ESensorType.SER_UNKNOWN

  @staticmethod
  def value_of(name: str) -> 'ESensorType':
    try:
      return ESensorType[name]
    except KeyError:
      return ESensorType.SER_UNKNOWN 







import pyhausbus.HausBusUtils as HausBusUtils
from enum import Enum

class ERegisterType(Enum):
  NONE=0
  eSignedWordHolding=2
  eSignedWordInput=3
  eUnsignedWordHolding=4
  eUnsignedWordInput=5
  eSignedDWordHolding=6
  eSignedDWordInput=7
  eUnsignedDWordHolding=8
  eUnsignedDWordInput=9
  eFloatHolding=10
  eFloatInput=11
  eVoltage=12
  eCurrent=13
  SER_UNKNOWN=-1

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    checkValue = HausBusUtils.bytesToInt(data, offset)
    for act in ERegisterType.__members__.values():
      if (act.value == checkValue):
        return act

    return ERegisterType.SER_UNKNOWN

  @staticmethod
  def value_of(name: str) -> 'ERegisterType':
    try:
      return ERegisterType[name]
    except KeyError:
      return ERegisterType.SER_UNKNOWN 







from pyhausbus.HausBusCommand import HausBusCommand
from pyhausbus.ABusFeature import *
from pyhausbus.ResultWorker import ResultWorker
import pyhausbus.HausBusUtils as HausBusUtils
from pyhausbus.de.hausbus.homeassistant.proxy.modbusSlave.data.Configuration import Configuration

class ModbusSlave(ABusFeature):
  CLASS_ID:int = 14

  def __init__ (self,objectId:int):
    super().__init__(objectId)

  @staticmethod
  def create(deviceId:int, instanceId:int):
    return ModbusSlave(HausBusUtils.getObjectId(deviceId, 14, instanceId))

  """
  """
  def getConfiguration(self):
    LOGGER.debug("getConfiguration")
    hbCommand = HausBusCommand(self.objectId, 0, "getConfiguration")
    ResultWorker()._setResultInfo(Configuration,self.getObjectId())
    hbCommand.send()


  """
  @param rtuGatewayDeviceId ID des Geraetes mit dem RTU Gateway.
  """
  def setConfiguration(self, rtuGatewayDeviceId:int):
    LOGGER.debug("setConfiguration"+" rtuGatewayDeviceId = "+str(rtuGatewayDeviceId))
    hbCommand = HausBusCommand(self.objectId, 1, "setConfiguration")
    hbCommand.addWord(rtuGatewayDeviceId)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()


  """
  @param rtuGatewayDeviceId ID des Geraetes mit dem RTU Gateway.
  """
  def Configuration(self, rtuGatewayDeviceId:int):
    LOGGER.debug("Configuration"+" rtuGatewayDeviceId = "+str(rtuGatewayDeviceId))
    hbCommand = HausBusCommand(self.objectId, 128, "Configuration")
    hbCommand.addWord(rtuGatewayDeviceId)
    ResultWorker()._setResultInfo(None,self.getObjectId())
    hbCommand.send()






import pyhausbus.HausBusUtils as HausBusUtils

class EvConfortable:
  CLASS_ID = 34
  FUNCTION_ID = 201

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvConfortable()

  def __str__(self):
    return f"EvConfortable()"






import pyhausbus.HausBusUtils as HausBusUtils

class SetConfiguration:
  CLASS_ID = 14
  FUNCTION_ID = 1

  def __init__(self,rtuGatewayDeviceId:int):
    self.rtuGatewayDeviceId=rtuGatewayDeviceId


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return SetConfiguration(HausBusUtils.bytesToWord(dataIn, offset))

  def __str__(self):
    return f"SetConfiguration(rtuGatewayDeviceId={self.rtuGatewayDeviceId})"

  '''
  @param rtuGatewayDeviceId ID des Geraetes mit dem RTU Gateway.
  '''
  def getRtuGatewayDeviceId(self):
    return self.rtuGatewayDeviceId






import pyhausbus.HausBusUtils as HausBusUtils
from enum import Enum

class ESiPrefix(Enum):
  eMicro=-6
  eMilli=-3
  eCenti=-2
  eDeci=-1
  eBase=0
  eDeka=1
  eHecto=2
  eKilo=3
  eMega=6
  SER_UNKNOWN=-1

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    checkValue = HausBusUtils.bytesToInt(data, offset)
    for act in ESiPrefix.__members__.values():
      if (act.value == checkValue):
        return act

    return ESiPrefix.SER_UNKNOWN

  @staticmethod
  def value_of(name: str) -> 'ESiPrefix':
    try:
      return ESiPrefix[name]
    except KeyError:
      return ESiPrefix.SER_UNKNOWN 







from pyhausbus.de.hausbus.homeassistant.proxy.modBusRTU.params.ERegisterType import ERegisterType
from pyhausbus.de.hausbus.homeassistant.proxy.modBusRTU.params.ESensorType import ESensorType
from pyhausbus.de.hausbus.homeassistant.proxy.modBusRTU.params.ESiPrefix import ESiPrefix
import pyhausbus.HausBusUtils as HausBusUtils

class RegisterConfiguration:
  CLASS_ID = 45
  FUNCTION_ID = 129

  def __init__(self,idx:int, node:int, registerType:ERegisterType, address:int, sensorType:ESensorType, siPrefix:ESiPrefix):
    self.idx=idx
    self.node=node
    self.registerType=registerType
    self.address=address
    self.sensorType=sensorType
    self.siPrefix=siPrefix


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return RegisterConfiguration(HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), ERegisterType._fromBytes(dataIn, offset), HausBusUtils.bytesToWord(dataIn, offset), ESensorType._fromBytes(dataIn, offset), ESiPrefix._fromBytes(dataIn, offset))

  def __str__(self):
    return f"RegisterConfiguration(idx={self.idx}, node={self.node}, registerType={self.registerType}, address={self.address}, sensorType={self.sensorType}, siPrefix={self.siPrefix})"

  '''
  @param idx index der Konfiguration.
  '''
  def getIdx(self):
    return self.idx

  '''
  @param node Knoten Nummer im BUS.
  '''
  def getNode(self):
    return self.node

  '''
  @param registerType Unterstuetzte Register Typen.
  '''
  def getRegisterType(self):
    return self.registerType

  '''
  @param address Register Adresse.
  '''
  def getAddress(self):
    return self.address

  '''
  @param sensorType Sensor Typ meldet sich dann mit der entsprechenden Feature-Klasse.
  '''
  def getSensorType(self):
    return self.sensorType

  '''
  @param siPrefix Si-Prefix f?r den Zahlenwert im ModBus-Register.
  '''
  def getSiPrefix(self):
    return self.siPrefix






import pyhausbus.HausBusUtils as HausBusUtils

class EvWarm:
  CLASS_ID = 32
  FUNCTION_ID = 201

  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return EvWarm()

  def __str__(self):
    return f"EvWarm()"






from pyhausbus.de.hausbus.homeassistant.proxy.controller.params.EType import EType
import pyhausbus.HausBusUtils as HausBusUtils

class SetSystemVariable:
  CLASS_ID = 0
  FUNCTION_ID = 16

  def __init__(self,type:EType, index:int, value:int):
    self.type=type
    self.index=index
    self.value=value


  @staticmethod
  def _fromBytes(dataIn:bytearray, offset):
    return SetSystemVariable(EType._fromBytes(dataIn, offset), HausBusUtils.bytesToInt(dataIn, offset), HausBusUtils.bytesToWord(dataIn, offset))

  def __str__(self):
    return f"SetSystemVariable(type={self.type}, index={self.index}, value={self.value})"

  '''
  @param type Hier wird der Typ der Variable.
  '''
  def getType(self):
    return self.type

  '''
  @param index Die Variablen liegen mehrfach vor 32xBIT.
  '''
  def getIndex(self):
    return self.index

  '''
  @param value Die Systemvariable wird mit diesem Wert belegt..
  '''
  def getValue(self):
    return self.value






import pyhausbus.HausBusUtils as HausBusUtils
from enum import Enum

class ELastEvent(Enum):
  LOW=200
  IN_RANGE=201
  HIGH=202
  SER_UNKNOWN=-1

  @staticmethod
  def _fromBytes(data:bytearray, offset):
    checkValue = HausBusUtils.bytesToInt(data, offset)
    for act in ELastEvent.__members__.values():
      if (act.value == checkValue):
        return act

    return ELastEvent.SER_UNKNOWN

  @staticmethod
  def value_of(name: str) -> 'ELastEvent':
    try:
      return ELastEvent[name]
    except KeyError:
      return ELastEvent.SER_UNKNOWN 




